Pro lris_info,filenames,outfile=outfile

;+----------------------------------------------------------------------
;
; LRIS_INFO      5/2004
;
; Extract useful information from a LRIS fits file header,
; including target name, integration time, slitmask, grism or grating
; info, arimass, etc..
;
; INPUTS
;        file     - String array of fits filenames.
;
; KEYWORDS
;        outfile  - File to which to direct output (one line per input
;                   fits file)
;
; PROGRAMS CALLED
;        strsetlen
;
; HISTORY
;        Modified from NIRSPEC_INFO 7/21/2004 GDB
;-----------------------------------------------------------------------

if (n_params() eq 0) then begin
   print,'CALLING SEQUENCE:  lris_info,filenames,outfile=outfile'
   return
endif

; Output to a file
tofile = 0    ; Default is standard output
if keyword_set(outfile) then begin
   openw,lun,outfile,/get_lun
   tofile = 1
endif

;;; Loop through input files and extract header information

filenames = [filenames]
nfiles = n_elements(filenames)

for i=0,nfiles-1 do begin
   
   ; Read header
   file = filenames(i)
   sxhread,file,hdr

   ; Red or Blue
   instrume = sxpar(hdr,'INSTRUME')

   ; Get Keywords and trim to specified length
   objname  = strsetlen(sxpar(hdr,'OBJECT'),18)
   naxis1   = strsetlen(sxpar(hdr,'NAXIS1'),6)
   naxis2   = strsetlen(sxpar(hdr,'NAXIS2'),6)
   rotmode  = strsetlen(sxpar(hdr,'ROTMODE'),15)
   rotposn  = strsetlen(sxpar(hdr,'ROTPOSN'),8)+'  ' 
   if (instrume eq 'LRISBLUE') then begin
      filter = strsetlen(sxpar(hdr,'BLUFILT'),7) 
      disp   = strsetlen(sxpar(hdr,'GRISNAME'),16) + '  '
   endif else begin
      filter = strsetlen(sxpar(hdr,'REDFILT'),7) 
      disp   = strsetlen(sxpar(hdr,'GRANAME'),10)
      disp   = disp + strsetlen(sxpar(hdr,'GRANGLE'),6) + '  '
   endelse
   dichname = strsetlen(sxpar(hdr,'DICHNAME'),6)
   slitname = strsetlen(sxpar(hdr,'SLITNAME'),10)
   time     = strsetlen(sxpar(hdr,'ELAPTIME'),6)
   ut       = strsetlen(sxpar(hdr,'UT'),13)
   airmass  = strsetlen(sxpar(hdr,'AIRMASS'),6)

   ; Print out results
   fileprint = strsetlen(file,16)
   entry = fileprint+objname+naxis1+naxis2+rotmode+rotposn+filter+disp+$
              dichname+slitname+time+ut+airmass
   if (tofile) then printf,lun,entry else print,entry

endfor

if (tofile) then close,lun

return
end


